@@ -1,10 +1,28 @@
 /*
- * Copyright (c) 2009-2011, The Regents of the University of California,
- * through Lawrence Berkeley National Laboratory (subject to receipt of any
- * required approvals from the U.S. Dept. of Energy).  All rights reserved.
+ * iperf, Copyright (c) 2014, 2015, The Regents of the University of
+ * California, through Lawrence Berkeley National Laboratory (subject
+ * to receipt of any required approvals from the U.S. Dept. of
+ * Energy).  All rights reserved.
  *
- * This code is distributed under a BSD style license, see the LICENSE file
- * for complete information.
+ * If you have questions about your rights to use or distribute this
+ * software, please contact Berkeley Lab's Technology Transfer
+ * Department at TTD@lbl.gov.
+ *
+ * NOTICE.  This software is owned by the U.S. Department of Energy.
+ * As such, the U.S. Government has been granted for itself and others
+ * acting on its behalf a paid-up, nonexclusive, irrevocable,
+ * worldwide license in the Software to reproduce, prepare derivative
+ * works, and perform publicly and display publicly.  Beginning five
+ * (5) years after the date permission to assert copyright is obtained
+ * from the U.S. Department of Energy, and subject to any subsequent
+ * five (5) year renewals, the U.S. Government is granted for itself
+ * and others acting on its behalf a paid-up, nonexclusive,
+ * irrevocable, worldwide license in the Software to reproduce,
+ * prepare derivative works, distribute copies to the public, perform
+ * publicly and display publicly, and to permit others to do so.
+ *
+ * This code is distributed under a BSD style license, see the LICENSE
+ * file for complete information.
  */
 
 #include <stdio.h>
@@ -280,28 +298,26 @@ Nsendfile(int fromfd, int tofd, const char *buf, size_t count)
 	offset = count - nleft;
 #ifdef linux
 	r = sendfile(tofd, fromfd, &offset, nleft);
-#else
-#ifdef __FreeBSD__
+	if (r > 0)
+	    nleft -= r;
+#elif defined(__FreeBSD__)
 	r = sendfile(fromfd, tofd, offset, nleft, NULL, &sent, 0);
-	if (r == 0)
-	    r = sent;
-#else
-#if defined(__APPLE__) && defined(__MACH__) && defined(MAC_OS_X_VERSION_10_6)	/* OS X */
+	nleft -= sent;
+#elif defined(__APPLE__) && defined(__MACH__) && defined(MAC_OS_X_VERSION_10_6)	/* OS X */
 	sent = nleft;
 	r = sendfile(fromfd, tofd, offset, &sent, NULL, 0);
-	if (r == 0)
-	    r = sent;
+	nleft -= sent;
 #else
 	/* Shouldn't happen. */
 	r = -1;
 	errno = ENOSYS;
-#endif
-#endif
 #endif
 	if (r < 0) {
 	    switch (errno) {
 		case EINTR:
 		case EAGAIN:
+		if (count == nleft)
+		    return NET_SOFTERROR;
 		return count - nleft;
 
 		case ENOBUFS:
@@ -311,9 +327,11 @@ Nsendfile(int fromfd, int tofd, const char *buf, size_t count)
 		default:
 		return NET_HARDERROR;
 	    }
-	} else if (r == 0)
+	}
+#ifdef linux
+	else if (r == 0)
 	    return NET_SOFTERROR;
-	nleft -= r;
+#endif
     }
     return count;
 }
