@@ -1,12 +1,29 @@
 /*
- * Copyright (c) 2009-2011, The Regents of the University of California,
- * through Lawrence Berkeley National Laboratory (subject to receipt of any
- * required approvals from the U.S. Dept. of Energy).  All rights reserved.
+ * iperf, Copyright (c) 2014, The Regents of the University of
+ * California, through Lawrence Berkeley National Laboratory (subject
+ * to receipt of any required approvals from the U.S. Dept. of
+ * Energy).  All rights reserved.
  *
- * This code is distributed under a BSD style license, see the LICENSE file
- * for complete information.
+ * If you have questions about your rights to use or distribute this
+ * software, please contact Berkeley Lab's Technology Transfer
+ * Department at TTD@lbl.gov.
+ *
+ * NOTICE.  This software is owned by the U.S. Department of Energy.
+ * As such, the U.S. Government has been granted for itself and others
+ * acting on its behalf a paid-up, nonexclusive, irrevocable,
+ * worldwide license in the Software to reproduce, prepare derivative
+ * works, and perform publicly and display publicly.  Beginning five
+ * (5) years after the date permission to assert copyright is obtained
+ * from the U.S. Department of Energy, and subject to any subsequent
+ * five (5) year renewals, the U.S. Government is granted for itself
+ * and others acting on its behalf a paid-up, nonexclusive,
+ * irrevocable, worldwide license in the Software to reproduce,
+ * prepare derivative works, distribute copies to the public, perform
+ * publicly and display publicly, and to permit others to do so.
+ *
+ * This code is distributed under a BSD style license, see the LICENSE
+ * file for complete information.
  */
-
 #ifndef __NET_H
 #define __NET_H
 
@@ -24,9 +41,7 @@ int getsockdomain(int sock);
 #define NET_SOFTERROR -1
 #define NET_HARDERROR -2
 
-unsigned long long htonll(unsigned long long);
-unsigned long long ntohll(unsigned long long);
-
+#ifndef htonll
 /* XXX: Need a better check for byte order */
 #if BYTE_ORDER == BIG_ENDIAN
 #define HTONLL(n) (n)
@@ -55,3 +70,4 @@ unsigned long long ntohll(unsigned long long);
 #define ntohll(n) NTOHLL(n)
 
 #endif
+#endif
